@@ -121,6 +121,7 @@ public interface ConnectorBundleErrorCodes {
 	int COMMAND_SYNC_CAN_NOT_CONVERT_ICAL_TO_MEETING_REQUEST = 0x61012D;
 	int COMMAND_SYNC_CAN_NOT_GET_MAIL_OR_MEETING_REQUEST = 0x61012E;
 	int COMMAND_DATA_OBJECT_NOT_FOUND_2 = 0x61012F;
+
 	int COMMAND_SYNC_RESULT_USM_ERROR = 0x610130;
 	int INITIALIZER_USM_JSON_ACCESS_DENIED_FOR_USER = 0x610131;
 	int INITIALIZER_NEW_FOLDER_TREE_MODULE_NOT_INSTALLED = 0x610132;
@@ -131,12 +132,17 @@ public interface ConnectorBundleErrorCodes {
 	int COMMAND_CANNOT_RESOLVE_DISTRIBUTION_LIST_MEMBER = 0x610137;
 	int COMMAND_DUPLICATE_UUID = 0x610138;
 	int SYNC_INSUFFICIENT_DELETION_RIGHTS = 0x610139;
+
 	int SYNC_INSUFFICIENT_CREATION_RIGHTS = 0x610140;
 	int SYNC_PIM_ATTACHMENT_CREATION_FAILED = 0x610141;
 	int SYNC_STORING_NEW_STATE_ON_IMAP_DOWN_FAILED = 0x610142;
 	int SYNC_RETREIVING_TRASH_FOLDER_FAILED = 0x610143;
 	int COMMAND_REJECTED_TOO_MANY_SYNCHRONIZATIONS = 0x610144;
 	int SYNC_CAN_NOT_CHANGE_CONFIRMATIONS_ERR1 = 0x610145;
+	int COMMAND_DB_ERROR_ON_READ_SHARED_FOLDER = 0x610146;
+	int COMMAND_DB_ERROR_ON_READ_SHARED_FOLDER_1 = 0x610147;
+	int COMMAND_DB_ERROR_ON_READ_EMAILS = 0x610148;
+	int COMMAND_DB_ERROR_ON_READ_EMAILS_1 = 0x610149;
 
 	// 610200-6102FF: Servlet error codes
 	int SERVLET_REGISTRATION_FAILED = 0x610200;
@@ -148,6 +154,7 @@ public interface ConnectorBundleErrorCodes {
 	int BAD_JSONOBJECT_IN_REQUEST = 0x610206;
 	int INVALID_ALIAS_FOR_SERVLET = 0x610207;
 	int EXCEPTION_IN_SERVLET = 0x610208;
+	int EXCEPTION_IN_SERVLET_2 = 0x610209;
 
 	// 610300-6103FF: Login error codes
 	int LOGIN_JSON_ERROR = 0x610300;
