@@ -418,7 +418,9 @@ public class MimeMailBuilder {
 			contentBytes = Toolkit.decodeBase64(decodedContent);
 		else
 			contentBytes = decodedContent.getBytes(charset);
-		part.setText(new String(contentBytes, charset), charset, subtype);
+	    part.setDataHandler(new DataHandler(new ByteArrayDataSource(contentBytes, contentTypeOfPart)));
+	    part.setHeader("Content-Type", contentTypeOfPart);
+	    // part.setText(new String(contentBytes, charset), charset, subtype);
 	}
 
 	private MimeMultipart buildMimePartForAlternative(JSONObject data) throws MessagingException, JSONException,
