@@ -48,15 +48,28 @@
  */
 package com.openexchange.usm.session.impl;
 
-import java.sql.*;
-import java.util.*;
+import java.io.Serializable;
+import java.sql.PreparedStatement;
+import java.sql.ResultSet;
+import java.sql.SQLException;
+import java.util.ArrayList;
+import java.util.BitSet;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
 
 import org.json.JSONObject;
 
-import com.openexchange.usm.api.contenttypes.*;
+import com.openexchange.usm.api.contenttypes.ContentType;
+import com.openexchange.usm.api.contenttypes.ContentTypeField;
+import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
 import com.openexchange.usm.api.database.DatabaseAccessException;
 import com.openexchange.usm.api.database.EncapsulatedConnection;
 import com.openexchange.usm.api.exceptions.USMException;
+import com.openexchange.usm.api.exceptions.USMResourceAccessException;
 import com.openexchange.usm.api.exceptions.USMSQLException;
 import com.openexchange.usm.api.session.ConflictResolution;
 import com.openexchange.usm.api.session.SessionInitializer;
@@ -68,7 +81,7 @@ import com.openexchange.usm.util.Toolkit;
  * @author afe
  *
  */
-public class PersistentSessionData {
+public class PersistentSessionData implements Serializable {
 	// Determines in ms. how often for constantly active sessions the internal cache of persistent data is updated (1/hour)
 	private final static long UPDATE_INTERVAL = 60L * 60L * 1000L;
 
@@ -327,8 +340,10 @@ public class PersistentSessionData {
 			Map<Integer, SessionInformation> sessionIDs = new HashMap<Integer, SessionInformation>();
 			while (result.next()) {
 				int usmSessionId = result.getInt(5);
-				sessionIDs.put(usmSessionId, new SessionInformation(result.getInt(1), result.getInt(2), result
-						.getString(3), result.getString(4), usmSessionId));
+				sessionIDs.put(
+						usmSessionId,
+						new SessionInformation(result.getInt(1), result.getInt(2), result.getString(3), result
+								.getString(4), usmSessionId));
 			}
 			return sessionIDs;
 		} finally {
@@ -384,8 +399,12 @@ public class PersistentSessionData {
 				_contentTypeFilter = contentTypeFilter;
 				_fields = fields;
 				_fieldView = Collections.unmodifiableMap(_fields);
-			} catch (DatabaseAccessException ignored) {
-			} catch (USMSQLException ignored) {
+			} catch (DatabaseAccessException e) {
+				throw new USMResourceAccessException(USMSessionManagementErrorCodes.PERSISTENT_SESSION_DB_ERROR_3,
+						"DB Access Exception on reading persistent fields", e);
+			} catch (USMSQLException e) {
+				throw new USMResourceAccessException(USMSessionManagementErrorCodes.PERSISTENT_SESSION_DB_ERROR_4,
+						"SQL Exception on reading persistent fields", e);
 			}
 		}
 	}
@@ -455,8 +474,11 @@ public class PersistentSessionData {
 				con.close();
 				con = null;
 				con = _session.getWritableDBConnection();
-				int sessionId = _session.getSessionManager().getDatabaseAccess().getNextIdFromSequence(
-						_session.getContextId(), PersistentSessionDataSQLStatements.SEQUENCE_TABLE_NAME);
+				int sessionId = _session
+						.getSessionManager()
+						.getDatabaseAccess()
+						.getNextIdFromSequence(_session.getContextId(),
+								PersistentSessionDataSQLStatements.SEQUENCE_TABLE_NAME);
 				statement = con
 						.prepareStatement("insert into USMSession (cid, id, device, protocol, usmSessionId) values(?,?,?,?,?)");
 				statement.setInt(1, _session.getContextId());
@@ -487,8 +509,8 @@ public class PersistentSessionData {
 			try {
 				_conflictResolution = ConflictResolution.valueOf(value);
 			} catch (IllegalArgumentException iae) {
-				_session.getSessionManager().getJournal().error(
-						_session + " Invalid ConflictResolution " + value + " in DB", iae);
+				_session.getSessionManager().getJournal()
+						.error(_session + " Invalid ConflictResolution " + value + " in DB", iae);
 			}
 		} else if (field.startsWith(FIELD_PREFIX)) {
 			fieldMap.put(field.substring(2), value);
@@ -634,8 +656,8 @@ public class PersistentSessionData {
 			addSessionIdenifierParamsToStatement(statement);
 			statement.setString(NUMBER_OF_SESSION_ID_FIELDS + 1, key);
 			if (statement.executeUpdate() != 1)
-				_session.getSessionManager().getJournal().warn(
-						_session + " Deleting field " + key + " in DB did not change any rows");
+				_session.getSessionManager().getJournal()
+						.warn(_session + " Deleting field " + key + " in DB did not change any rows");
 		} catch (SQLException e) {
 			String errorMessage = _session + " SQL error while updating field " + key;
 			throw new USMSQLException(USMSessionManagementErrorCodes.PERSISTENT_SESSION_ERROR_NUMBER2, errorMessage, e);
@@ -664,8 +686,8 @@ public class PersistentSessionData {
 					+ PersistentSessionDataSQLStatements.UNIQUE_SESSION_IDENTIFIER);
 			addSessionIdenifierParamsToStatement(statement);
 			if (statement.executeUpdate() != 1)
-				_session.getSessionManager().getJournal().warn(
-						_session + " Deleting session in DB did not change any rows");
+				_session.getSessionManager().getJournal()
+						.warn(_session + " Deleting session in DB did not change any rows");
 		} catch (SQLException e) {
 			String errorMessage = _session + " SQL error while deleting fields ";
 			throw new USMSQLException(USMSessionManagementErrorCodes.PERSISTENT_SESSION_ERROR_NUMBER4, errorMessage, e);
@@ -702,8 +724,8 @@ public class PersistentSessionData {
 				statement.setString(NUMBER_OF_SESSION_ID_FIELDS + 2, value);
 			}
 			if (statement.executeUpdate() != 1)
-				_session.getSessionManager().getJournal().warn(
-						_session + " Setting field " + key + " in DB did not change any rows");
+				_session.getSessionManager().getJournal()
+						.warn(_session + " Setting field " + key + " in DB did not change any rows");
 			con.commit();
 		} catch (SQLException e) {
 			String errorMessage = _session + " SQL error while updating field " + key;
@@ -720,8 +742,8 @@ public class PersistentSessionData {
 				try {
 					con.setAutoCommit(true);
 				} catch (SQLException e) {
-					_session.getSessionManager().getJournal().error(
-							_session + " SQL error: setAutocommit(false) failed", e);
+					_session.getSessionManager().getJournal()
+							.error(_session + " SQL error: setAutocommit(false) failed", e);
 				}
 				Toolkit.close(con);
 			}
